#
# spec file for package perl-MP3-Tag
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MP3-Tag
Name:           perl-MP3-Tag
Version:        1.160.0
Release:        150500.4.pm.1
# 1.16 -> normalize -> 1.160.0
%define cpan_version 1.16
#Upstream:  reserved. This program is free software; you can redistribute it and/or modify it under the terms of the Artistic License, distributed with Perl.
License:        Artistic-2.0
Summary:        Module for reading tags of MP3 audio files
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/I/IL/ILYAZ/modules/%{cpan_name}-%{cpan_version}.zip
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Encode::transliterate_win1251)
Provides:       perl(MP3::Tag)
Provides:       perl(MP3::Tag::CDDB_File)
Provides:       perl(MP3::Tag::Cue)
Provides:       perl(MP3::Tag::File)
Provides:       perl(MP3::Tag::ID3v1)
Provides:       perl(MP3::Tag::ID3v2) = 1.140.0
Provides:       perl(MP3::Tag::ImageExifTool)
Provides:       perl(MP3::Tag::ImageSize)
Provides:       perl(MP3::Tag::Implemenation)
Provides:       perl(MP3::Tag::Inf)
Provides:       perl(MP3::Tag::LastResort)
Provides:       perl(MP3::Tag::ParseData)
Provides:       perl(MP3::Tag::__hasparent)
Provides:       perl(MP3::Tag::__proxy)
Provides:       perl(Normalize::Text::Music_Fields) = 0.20.0
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  unzip
# MANUAL END

%description
'MP3::Tag' is a wrapper module to read different tags of mp3 files. It
provides an easy way to access the functions of separate modules which do
the handling of reading/writing the tags itself.

At the moment MP3::Tag::ID3v1 and MP3::Tag::ID3v2 are supported for read
and write; MP3::Tag::ImageExifTool, MP3::Tag::Inf, MP3::Tag::CDDB_File,
MP3::Tag::File, MP3::Tag::Cue, MP3::Tag::ImageSize, MP3::Tag::LastResort
are supported for read access (the information obtained by Image::ExifTool
(if present), parsing CDDB files, _.inf_ file, the filename, and _.cue_
file, and obtained via Image::Size) (if present).

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc cddb.tm cddb.tmp Changes examples README.shrink README.txt test.mp3 TODO

%changelog
* Sat Nov 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.16
  see /usr/share/doc/packages/perl-MP3-Tag/Changes
* Mon Jun  7 2021 Daniel Donisa <daniel.donisa@suse.com>
- Update spec
  * Fix cpanspec.yml
  * Shrink %%description
  * Remove BuildRoot and %%defattr
  * Upgrade %%setup to %%autosetup
  * Upgrade make calls to %%make_build macros
* Wed Sep  4 2019 olaf@aepfle.de
- Pick a License string that makes SLE15_SP1 happy
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- Update to 1.15
  Tag.pm: Fix more unescaped-{ warnings (thanks to Christian Walde etc).
* Thu Sep 29 2016 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-MP3-Tag/Changes
  Release Name: 1.14
  ====================
  Tag.pm: Quiet warnings from 5.22.
  Start implementing handlers: instead of FRAM(langs)[opts], one can use, e.g., func_name(ID3v1,Cue)[arg1][arg2]
  [#] ID3v2::_frame_select_by_descr is missing //s
  New configuration variable ampersand_joiner (default '; ').
  New method _auto_field_from() (abstracted from _auto_field()).
  Change logic of calling ->can() in _auto_field_from().
  _parse_rex_microinterpolate() would not update $ecount on seeing %%%%.
  When parsing with %%=c etc: with %%==c the match fails if there is no comment.
  (Checked the same way as for %%{c:}.)
  Support some of %%-escapes not being matched (e.g, due to alternatives in a REx).
  (0-length matches were ignored anyway [when join()ing].)
  parse_rex(), parse_rex_match() may return an extra result (if %%{handler}s are present).
  Recognize ID3v2 frame names as [A-Z]{3}[A-Z\d] (was \w{4}).
  (Detection frame/vs/handler happens via PACKAGES; so if lang codes inf/cue appear, we may be in trouble.)
  Use the same code in parse(_rex)?_prepare.  (Now parse() allows the same %%-constructs as parse_rex().)
  ID3v2.pm:
  New method have_one_of_frames().
  New methods *_have() (for simplest fields: title, comment, track, artist, album, genre, year).
  ImageExifTool.pm:
  Comprehensive docs.
* Fri Mar 18 2011 pascal.bleser@opensuse.org
- initial version (1.13)
